@@ -72,6 +72,7 @@ class FileSystemManager(object):
         'btrfs-compress': {'defaultopt': defaultOpt,
                   'format': '/sbin/mkfs.btrfs',
                   'orig': 'btrfs',
+                  'compress': "compress=%s",
                   'formatparam': '{labelparam} -f {device}',
                   'gpt': '8300',
                   'label': '-L {labelname}',
@@ -152,6 +153,7 @@ class FileSystemManager(object):
     default_param = {'defaultopt': defaultOpt,
                      'gpt': '8300',
                      'msdos': '83',
+                     'compress': None,
                      'ssd': []}
 
     @classmethod
@@ -179,10 +181,12 @@ class FileSystemManager(object):
     }
 
     @classmethod
-    def getDefaultOpt(cls, fs, ssd=False):
-        return ",".join(cls.supportFS.get(fs, cls.default_param)['defaultopt'] +
-                        (cls.supportFS.get(fs, cls.default_param)['ssd']
-                         if ssd else []))
+    def getDefaultOpt(cls, fs, ssd=False, compress=None):
+        fsopts = cls.supportFS.get(fs, cls.default_param)
+        return ",".join(fsopts['defaultopt'] +
+                        (fsopts['ssd'] if ssd else []) +
+                        ([fsopts['compress'] % compress]
+                         if fsopts['compress'] and compress else []))
 
     @classmethod
     def checkFSForTypeMount(cls, fs, roottype, mp):
