@@ -1784,7 +1784,9 @@ class VariableOsInstallDiskOptions(ReadonlyVariable):
                 else:
                     all_ssd = all(x in ssd_devices
                                   for x in disk_parent.split(','))
-                    yield FileSystemManager.getDefaultOpt(disk_format, all_ssd)
+                    compression = self.Get('os_install_btrfs_compression')
+                    yield FileSystemManager.getDefaultOpt(disk_format, all_ssd,
+                        compression)
 
         return list(generator())
 
